@@ -9,13 +9,13 @@ setMethod(
     pars <- getPar(object)
     if(any(targets<=pars$params$bottom)){
       targets[which(targets<=pars$params$bottom)] <- min(getFitValues(object))
-      warning("One (or more) of the provided values were below the estimated bottom asymptote.",
+      warning("One (or more) of the provided values were less or equal to the estimated bottom asymptote.",
               call.=FALSE, immediate.=TRUE)
       message("These values have been replaced by the minimal possible value the model can estimate.")
     }
     if(any(targets>=pars$params$top)){
       targets[which(targets>=pars$params$top)] <- max(getFitValues(object))
-      warning("One (or more) of the values were above the estimated top asymptote.",
+      warning("One (or more) of the values were greater or equal to the estimated top asymptote.",
               call.=FALSE, immediate.=TRUE)
       message("These values have been replaced by the maximal possible value the model can estimate.")
     }
